==> echobase-ui-2.1-sources.jar: fr/ifremer/echobase/ui/actions/exportDb/Download.java <==
/*
 * #%L
 * EchoBase :: UI
 * 
 * $Id: Download.java 589 2012-09-02 15:11:02Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/echobase/tags/echobase-2.1/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/exportDb/Download.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.echobase.ui.actions.exportDb;

import fr.ifremer.echobase.services.exportdb.ExportDbConfiguration;
import fr.ifremer.echobase.ui.actions.EchoBaseActionSupport;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;

/**
 * Download the result of the complete db export.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class Download extends EchoBaseActionSupport {

    private static final long serialVersionUID = 1L;

    /** Input stream of the file to download. */
    protected transient InputStream inputStream;

    /** File name of the download. */
    protected String fileName;

    /** Length of the file to download. */
    protected long contentLength;

    /** Content type of the file to download. */
    protected String contentType;

    public InputStream getInputStream() {
        return inputStream;
    }

    public String getFileName() {
        return fileName;
    }

    public long getContentLength() {
        return contentLength;
    }

    public String getContentType() {
        return contentType;
    }

    @Override
    public String execute() throws Exception {

        ExportDbConfiguration model =
                getEchoBaseSession().getActionConfiguration(ExportDbConfiguration.class);

        if (model == null) {
            addFlashError(_("echobase.error.no.exportDb.configurationFound"));
            return ERROR;
        }

        File exportFile = model.getExportFile();
        if (exportFile == null) {
            addFlashError(_("echobase.error.no.exportDb.exportFileFound"));
            return ERROR;
        }

        fileName = exportFile.getName();
        contentType = "application/zip";
        contentLength = exportFile.length();
        inputStream = new BufferedInputStream(new FileInputStream(exportFile));

        return SUCCESS;
    }
}

==> echobase-ui-2.2-sources.jar: fr/ifremer/echobase/ui/actions/exportDb/Download.java <==
/*
 * #%L
 * EchoBase :: UI
 * 
 * $Id: Download.java 842 2013-08-15 10:53:16Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/echobase/tags/echobase-2.2/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/exportDb/Download.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.echobase.ui.actions.exportDb;

import fr.ifremer.echobase.services.service.exportdb.ExportDbConfiguration;
import fr.ifremer.echobase.ui.actions.EchoBaseActionSupport;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;

/**
 * Download the result of the complete db export.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class Download extends EchoBaseActionSupport {

    private static final long serialVersionUID = 1L;

    /** Input stream of the file to download. */
    protected transient InputStream inputStream;

    /** File name of the download. */
    protected String fileName;

    /** Length of the file to download. */
    protected long contentLength;

    /** Content type of the file to download. */
    protected String contentType;

    public InputStream getInputStream() {
        return inputStream;
    }

    public String getFileName() {
        return fileName;
    }

    public long getContentLength() {
        return contentLength;
    }

    public String getContentType() {
        return contentType;
    }

    @Override
    public String execute() throws Exception {

        ExportDbConfiguration model =
                getEchoBaseSession().getActionConfiguration(ExportDbConfiguration.class);

        if (model == null) {
            addFlashError(_("echobase.error.no.exportDb.configurationFound"));
            return ERROR;
        }

        File exportFile = model.getExportFile();
        if (exportFile == null) {
            addFlashError(_("echobase.error.no.exportDb.exportFileFound"));
            return ERROR;
        }

        fileName = exportFile.getName();
        contentType = "application/zip";
        contentLength = exportFile.length();
        inputStream = new BufferedInputStream(new FileInputStream(exportFile));

        return SUCCESS;
    }
}
